chartpy creates a simple easy to use API to plot in a number of great Python chart libraries like plotly (via cufflinks),
bokeh and matplotlib, with a unified interface. You simply need to change a single keyword to change which chart engine
to use (see below), rather than having to learn the low level details of each library. I've also created new stylesheets
and formatting to ensure that the default matplotlib styling looks more modern using Open Sans font. The library
also works well with Dash, plotly's web server library built on top of Flask.